@@ -133,7 +133,7 @@ ogs_sbi_request_t *amf_nsmf_pdusession_build_create_sm_context(
     sNssai.sd = ogs_s_nssai_sd_to_string(sess->s_nssai.sd);
     SmContextCreateData.s_nssai = &sNssai;
 
-    if (sess->mapped_hplmn.sst) {
+    if (sess->mapped_hplmn_presence) {
         hplmnSnssai.sst = sess->mapped_hplmn.sst;
         hplmnSnssai.sd = ogs_s_nssai_sd_to_string(sess->mapped_hplmn.sd);
         SmContextCreateData.hplmn_snssai = &hplmnSnssai;
@@ -190,14 +190,25 @@ ogs_sbi_request_t *amf_nsmf_pdusession_build_create_sm_context(
         goto end;
     }
 
+    /*
+     * We're experiencing an issue after changing SearchResult.validityTime
+     * from 3600 seconds to 30 seconds. (#3210)
+     *
+     * When AMF finds a PCF through Discovery, it can be deleted
+     * after 30 seconds by ValidityTime.
+     *
+     * We have changed our implementation to not send the PCF-ID in this case.
+     *
+     * What we need to do is proactively add a part that will re-discover
+     * the PCF when a situation arises where we really need the PCF-ID.
+     */
     pcf_nf_instance = OGS_SBI_GET_NF_INSTANCE(
             amf_ue->sbi.service_type_array[
             OGS_SBI_SERVICE_TYPE_NPCF_AM_POLICY_CONTROL]);
-    if (!pcf_nf_instance) {
+    if (pcf_nf_instance)
+        SmContextCreateData.pcf_id = pcf_nf_instance->id;
+    else
         ogs_error("No pcf_nf_instance");
-        goto end;
-    }
-    SmContextCreateData.pcf_id = pcf_nf_instance->id;
 
     message.SmContextCreateData = &SmContextCreateData;
 
@@ -426,7 +437,10 @@ ogs_sbi_request_t *amf_nsmf_pdusession_build_release_sm_context(
             ngApCause.value = param->ngApCause.value;
         }
 
-        SmContextReleaseData._5g_mm_cause_value = param->gmm_cause;
+        if (param->gmm_cause) {
+            SmContextReleaseData._5g_mm_cause_value = param->gmm_cause;
+            SmContextReleaseData.is__5g_mm_cause_value = true;
+        }
     }
 
     memset(&ueLocation, 0, sizeof(ueLocation));
